<?php
namespace Teknisa\GQL\Modules\Atendimento\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\Report\ReportService;

class Gql01400EmissaoOcorrenciaAtendimentoController extends \Zeedhi\Framework\Controller\Report
{
    protected $qr2Strategy;
    protected $stNomeRel;
    protected $stExtensao;
    protected $entityManager;
    protected $novoCodigo;
    protected $connection;
    protected $environment;
    protected $birtStrategy;
    protected $fileServerPath;
    
    public function __construct(reportService $reportService, $qr2Strategy,$entityManager,$novoCodigo,$environment,$connection,$birtStrategy, $fileServerPath) 
    {
        parent::__construct($reportService);
        $this->qr2Strategy        = $qr2Strategy;
        $this->entityManager      = $entityManager;
        $this->novoCodigo         = $novoCodigo;
        $this->environment        = $environment;
        $this->connection         = $connection;
        $this->birtStrategy       = $birtStrategy;
        $this->fileServerPath    = $fileServerPath;
    }
    
    protected $reportMapping = array ();
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();
        $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
        $this->stNomeRel = $this->getReportName($row);

         if( $row['UNIDADE']=='T'){
            $row['UNIDADE']=$this->retornaFiliais($row);
        }
        if($row['FORNECEDOR']=='T'){
            $row['FORNECEDOR']=$this->retornaFornecedores($row);
        }
         $row['UNIDADE']=$this->criarListaValores($row['UNIDADE']);
        $row['FORNECEDOR']=$this->criarListaValores($row['FORNECEDOR']);
        $row['STATUS']=$this->criarListaValores($row['STATUS']);
        $row['P_NRORG'] = $this->environment->getNrorgTrab();
        $row["STRATEGY"]='BIRT';
        $row["URL"]=$this->fileServerPath;
        $this->reportMapping[$this->stNomeRel] =
        array (
            'strategy' => $row["STRATEGY"],
            
            'parameterMapping' => 
            array (
                'DATAINI'       => 'P_DATAINI',
                'DATAFIN'       => 'P_DATAFIN',
                'STATUS'        => 'L_STATUS',
                'UNIDADE'       => 'L_CDFILIAL',
                'FORNECEDOR'    => 'L_CDFORNECED',
                'INADEQUACAO'   => 'P_INADEQUA',
                'P_NRORG'       => 'P_NRORG',
                'CDPICTPROD'    => 'P_CDPICTPROD',
                'URL'           => 'P_URL'
            ),
        );
      
    }
       //insere lista no banco
    public function insertLista($nrlista, $cdlista) {
        $params = array(
            "NRLISTA" => $nrlista,
            "CDLISTA" => $cdlista
        );
        
        $sql = "INSERT INTO LISTA (NRLISTA, CDLISTA) VALUES (:NRLISTA, :CDLISTA)";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
     //apaga lista do banco
    public function deleteLista($nrlista) {
        $params = array(
            "NRLISTA" => $nrlista
        );
        
        $sql = "DELETE FROM LISTA WHERE NRLISTA =:NRLISTA";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }
    //cria lista de valores recebendo string como parametro
    public function criarListaValores($valores){
       
            $this->entityManager->beginTransaction();
            $lista = explode('_',$valores);
            $nrlista = $this->novoCodigo->getCodeByTableName('LISTA', $this->environment->getNrorgTrab(), 1, 10, false);
            try{
                foreach($lista as $key){
                    $this->insertLista($nrlista, $key);
                }
                $this->entityManager->commit();
                return $nrlista;
            } catch(\Exception $e){
                $this->entityManager->rollback();
                throw $e;
            }
        
    }
    private function insereLista($nrlista, $filiserv) {
		$rows = array();
		foreach($filiserv as $filialservico){
			array_push($rows,
				array(
					"NRLISTA" 	=> $nrlista,
					"CDLISTA" 	=> $filialservico,
					"__is_new"  => true
				)
			);
		}
		$dataSet = new DataSet(null, $rows);
		$request = new DTO\Request\DataSet($dataSet, '', '', '');
		$rowsToSave = $this->crudService->getRowsToSave($request, 'lista');
		$this->crudService->save('lista', $rowsToSave);
	}

    public function retornaFiliais(){
           $sql = "SELECT CDFILIAL FROM FILIAL";

        try {
            $filial = $this->entityManager->getConnection()->fetchAll($sql);
            return implode('_', array_column($filial, 'CDFILIAL'));
        } catch (\Exception $e) {
            throw $e;
        }
    }
     public function retornaFornecedores(){
         $sql = "SELECT CDFORNECED FROM FORNECEDOR";

        try {
            $fornecedor = $this->entityManager->getConnection()->fetchAll($sql);
            return implode('_', array_column($fornecedor, 'CDFORNECED'));
        } catch (\Exception $e) {
            throw $e;
        }
     }

}