<?php

namespace Teknisa\GQL\Modules\Cadastros\Services;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;

class gql00703QualificacaoDeFornecedoresService
{
    protected $connection;
    
    public function __construct($entityManager, $environment)
    {
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
    }
    
    /********************
     *      SELECTS     *
     * ******************/
    
    public function findDataFornecedor ()
    {
        $params = array();
        
        $query = "SELECT 
                        MIN(DTVALQUALIF) AS DTMENOR,
                        MAX(DTVALQUALIF) AS DTMAIOR
                  FROM 
                        FORNECEDOR";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function findDataCliente ()
    {
        $params = array();
        
        $query = "SELECT 
                        MIN(DTVALQUALIC) AS DTMENOR,
                        MAX(DTVALQUALIC) AS DTMAIOR
                  FROM 
                        CLIENTE";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function findDataProspect ()
    {
        $params = array();
        
        $query = "SELECT 
                        MIN(DTVALQUALIP) AS DTMENOR,
                        MAX(DTVALQUALIP) AS DTMAIOR
                  FROM 
                        PROSPECT";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function findDataFabricante ()
    {
        $params = array();
        
        $query = "SELECT 
                        MIN(DTVALQUALIF) AS DTMENOR,
                        MAX(DTVALQUALIF) AS DTMAIOR
                  FROM 
                        FABRICANTE";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function getHistoricoAlteracaoFornecedor ($row)
    {
        $params = [
            'P_CDFORNECED'       => $row['CDFORNECED'],
            'P_DTINICIAL'        => $row['DTINICIAL'],
            'P_DTFINAL'          => $row['DTFINAL'],
            'P_CDQUALIF'         => $row['CDQUALIF'],
            'P_TODOS'            => $row['ALLDATE'],
            'P_PERMITE'          => $row['PERMITE'],
            'P_NPERMITE'         => $row['NPERMITE'],
            'P_NDEFINIDO'        => $row['NDEFINIDO'],
        ];
        
        $query = "SELECT
                       F.CDFORNECED
                    FROM FORNECEDOR F
                    WHERE
                       ((INSTR(:P_CDFORNECED, F.CDFORNECED) <> 0) OR :P_CDFORNECED = 'T') AND
                       ((F.DTVALQUALIF  BETWEEN :P_DTINICIAL  AND :P_DTFINAL) OR (:P_TODOS = 'T'))  AND
                       EXISTS ( SELECT 5
                       			FROM QUALIFICACAO Q
                                WHERE
                       			  (Q.CDQUALIF = F.CDQUALIF) AND
                       	  		  ((INSTR(:P_CDQUALIF, Q.CDQUALIF) <> 0) OR :P_CDQUALIF = 'T') AND
                       		 	  ((Q.IDPERCOTCMP IN (:P_PERMITE, :P_NPERMITE)) OR (F.CDQUALIF IS NULL AND :P_NDEFINIDO = 'V')))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function getHistoricoQualificacaoFornecedor ($row)
    {
        $params = [
            'CDFORNECED'       => $row['CDFORNECED'],
        ];
        
        $query = "SELECT CDFORNECED,
                    TXHISQUALFOR AS TXHISQUALFOR
                  FROM HISTQUALFORN
                  WHERE (CDFORNECED = :CDFORNECED)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function getHistoricoAlteracaoCliente ($row)
    {
        $params = [
            'P_CDFORNECED'       => $row['CDFORNECED'],
            'P_DTINICIAL'        => $row['DTINICIAL'],
            'P_DTFINAL'          => $row['DTFINAL'],
            'P_CDQUALIF'         => $row['CDQUALIF'],
            'P_TODOS'            => $row['ALLDATE'],
            'P_PERMITE'          => $row['PERMITE'],
            'P_NPERMITE'         => $row['NPERMITE'],
            'P_NDEFINIDO'        => $row['NDEFINIDO'],
        ];
        
        $query = "SELECT
                       C.CDCLIENTE
                    FROM CLIENTE C
                    WHERE
                       ((INSTR(:P_CDFORNECED, C.CDCLIENTE) <> 0) OR :P_CDFORNECED = 'T') AND
                       ((C.DTVALQUALIC  BETWEEN :P_DTINICIAL  AND :P_DTFINAL) OR (:P_TODOS = 'T'))  AND
                       EXISTS ( SELECT 5
                       			FROM QUALIFICACAO Q
                                WHERE
                       			  (Q.CDQUALIF = C.CDQUALIF) AND
                       	  		  ((INSTR(:P_CDQUALIF, Q.CDQUALIF) <> 0) OR :P_CDQUALIF = 'T') AND
                       		 	  ((Q.IDPERCOTCMP IN (:P_PERMITE, :P_NPERMITE)) OR (C.CDQUALIF IS NULL AND :P_NDEFINIDO = 'V')))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function getHistoricoQualificacaoCliente ($row)
    {
        $params = [
            'CDCLIENTE'       => $row['CDCLIENTE'],
        ];
        
        $query = "SELECT CDCLIENTE,
                    TXHISQUALCLI AS TXHISQUALCLI
                  FROM HISTQUALCLIE
                  WHERE (CDCLIENTE = :CDCLIENTE)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function getHistoricoAlteracaoProspect ($row)
    {
        $params = [
            'P_CDFORNECED'       => $row['CDFORNECED'],
            'P_DTINICIAL'        => $row['DTINICIAL'],
            'P_DTFINAL'          => $row['DTFINAL'],
            'P_CDQUALIF'         => $row['CDQUALIF'],
            'P_TODOS'            => $row['ALLDATE'],
            'P_PERMITE'          => $row['PERMITE'],
            'P_NPERMITE'         => $row['NPERMITE'],
            'P_NDEFINIDO'        => $row['NDEFINIDO'],
        ];
        
        $query = "SELECT
                       P.CDPROSPECT
                    FROM PROSPECT P
                    WHERE
                       ((INSTR(:P_CDFORNECED, P.CDPROSPECT) <> 0) OR :P_CDFORNECED = 'T') AND
                       ((P.DTVALQUALIP  BETWEEN :P_DTINICIAL  AND :P_DTFINAL) OR (:P_TODOS = 'T'))  AND
                       EXISTS ( SELECT 5
                       			FROM QUALIFICACAO Q
                                WHERE
                       			  (Q.CDQUALIF = P.CDQUALIF) AND
                       	  		  ((INSTR(:P_CDQUALIF, Q.CDQUALIF) <> 0) OR :P_CDQUALIF = 'T') AND
                       		 	  ((Q.IDPERCOTCMP IN (:P_PERMITE, :P_NPERMITE)) OR (P.CDQUALIF IS NULL AND :P_NDEFINIDO = 'V')))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function getHistoricoQualificacaoProspect ($row)
    {
        $params = [
            'CDPROSPECT'       => $row['CDPROSPECT'],
        ];
        
        $query = "SELECT CDPROSPECT,
                    TXHISQUALPRO AS TXHISQUALPRO
                  FROM HISTQUALPROS
                  WHERE (CDPROSPECT = :CDPROSPECT)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function getHistoricoAlteracaoFabricante ($row)
    {
        $params = [
            'P_CDFORNECED'       => $row['CDFORNECED'],
            'P_DTINICIAL'        => $row['DTINICIAL'],
            'P_DTFINAL'          => $row['DTFINAL'],
            'P_CDQUALIF'         => $row['CDQUALIF'],
            'P_TODOS'            => $row['ALLDATE'],
            'P_PERMITE'          => $row['PERMITE'],
            'P_NPERMITE'         => $row['NPERMITE'],
            'P_NDEFINIDO'        => $row['NDEFINIDO'],
        ];
        
        $query = "SELECT
                       B.CDFABRIC
                    FROM FABRICANTE B
                    WHERE
                       ((INSTR(:P_CDFORNECED, B.CDFABRIC) <> 0) OR :P_CDFORNECED = 'T') AND
                       ((B.DTVALQUALIF  BETWEEN :P_DTINICIAL  AND :P_DTFINAL) OR (:P_TODOS = 'T'))  AND
                       EXISTS ( SELECT 5
                       			FROM QUALIFICACAO Q
                                WHERE
                       			  (Q.CDQUALIF = B.CDQUALIF) AND
                       	  		  ((INSTR(:P_CDQUALIF, B.CDQUALIF) <> 0) OR :P_CDQUALIF = 'T') AND
                       		 	  ((Q.IDPERCOTCMP IN (:P_PERMITE, :P_NPERMITE)) OR (B.CDQUALIF IS NULL AND :P_NDEFINIDO = 'V')))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function getHistoricoQualificacaoFabricante ($row)
    {
        $params = [
            'CDFABRICANTE'       => $row['CDFABRIC'],
        ];
        
        $query = "SELECT CDFABRICANTE,
                    TXHISQUALFAB AS TXHISQUALFAB
                  FROM HISTQUALFAB
                  WHERE (CDFABRICANTE = :CDFABRICANTE)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function selectOperador($row)
    {
        $params = array(
            'P_CDOPERADOR' => $row['CDOPERADOR']
                
        );
        
        $query = "SELECT
                    CDOPERADOR,
                    NMOPERADOR,
                    CDSENHOPER
                FROM
                    OPERADOR
                WHERE
                    CDOPERADOR = :P_CDOPERADOR";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
            return $std->fetchAll();
        } catch (Exception $e) {
            throw $e;
        }
    }

    /********************
     *      UPDATES     *
     * ******************/
     
    public function updateQualificacaoFornecedor ($row)
    {
        $params = [
            'CDQUALIF'    => $row['CDQUALIF'],
            'DTVALQUALIF' => $row['DTVALQUALIF'],
            'NRNOTAFORN'  => $row['NRNOTAFORN'],
            'IDFORNAUTO'  => $row['IDFORNAUTO'],
            'IDPERCMPDFE' => $row['IDPERCMPDFE'],
            'NRALVARA'    => $row['NRALVARA'],
            'IDUTALVARA'  => $row['IDUTALVARA'],
            'DTALVARA'    => $row['DTALVARA'],
            'CDFORNECED'  => $row['CDFORNECED'],
        ];
        $query = "UPDATE FORNECEDOR
                  SET
                    CDQUALIF     = :CDQUALIF,
                    DTVALQUALIF  = :DTVALQUALIF,
                    NRNOTAFORN   = :NRNOTAFORN,
                    IDFORNAUTO   = :IDFORNAUTO,
                    IDPERCMPDFE  = :IDPERCMPDFE,
                    NRALVARAFORN = :NRALVARA,
                    IDUTLALVFORN = :IDUTALVARA,
                    DTALVARAFORN = :DTALVARA
                  WHERE
                    CDFORNECED   = :CDFORNECED";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function updateQualificacaoCliente($row)
    {
        $params = [
            'CDQUALIF'    => $row['CDQUALIF'],
            'DTVALQUALIF' => $row['DTVALQUALIF'],
            'NRNOTAFORN'  => $row['NRNOTAFORN'],
            'IDFORNAUTO'  => $row['IDFORNAUTO'],
            'NRALVARA'    => $row['NRALVARA'],
            'IDUTALVARA'  => $row['IDUTALVARA'],
            'DTALVARA'    => $row['DTALVARA'],
            'CDFORNECED'  => $row['CDFORNECED'],
        ];
        
        $query = "UPDATE CLIENTE
                    SET 
                      CDQUALIF        = :CDQUALIF,
                      DTVALQUALIC     = :DTVALQUALIF,
                      NRNOTACLIE      = :NRNOTAFORN,
                      IDCLIEAUTO      = :IDFORNAUTO,
                      NRALVARACLI     = :NRALVARA,
                      IDUTLALVCLIE    = :IDUTALVARA,
                      DTVALIALVARACLI = :DTALVARA
                    WHERE 
                      CDCLIENTE   = :CDFORNECED";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function updateQualificacaoProspect($row)
    {
        $params = [
            'CDQUALIF'    => $row['CDQUALIF'],
            'DTVALQUALIF' => $row['DTVALQUALIF'],
            'NRNOTAFORN'  => $row['NRNOTAFORN'],
            'IDFORNAUTO'  => $row['IDFORNAUTO'],
            'NRALVARA'    => $row['NRALVARA'],
            'IDUTALVARA'  => $row['IDUTALVARA'],
            'DTALVARA'    => $row['DTALVARA'],
            'CDFORNECED'  => $row['CDFORNECED'],
        ];
        
        $query = "UPDATE PROSPECT
                    SET 
                      CDQUALIF     = :CDQUALIF,
                      DTVALQUALIP  = :DTVALQUALIF,
                      NRNOTAPROS   = :NRNOTAFORN,
                      IDPROSAUTO   = :IDFORNAUTO,
                      NRALVARAPROS = :NRALVARA,
                      IDUTLALVPROS = :IDUTALVARA,
                      DTALVARAPROS = :DTALVARA
                    WHERE 
                      CDPROSPECT   = :CDFORNECED";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function updateQualificacaoFabricante($row)
    {
        $params = [
            'CDQUALIF'    => $row['CDQUALIF'],
            'DTVALQUALIF' => $row['DTVALQUALIF'],
            'IDPERCMPDFE' => $row['IDPERCMPDFE'],
            'CDFORNECED'  => $row['CDFORNECED'],
        ];
        
        $query = "UPDATE FABRICANTE
                    SET 
                      CDQUALIF    = :CDQUALIF,
                      DTVALQUALIF = :DTVALQUALIF,
                      IDPERCMPDFE = :IDPERCMPDFE
                    WHERE 
                      CDFABRIC    = :CDFORNECED";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function updateDataQualificacaoFornecedor ($row)
    {
        $params = [
            'P_CDFORNECED'       => $row['CDFORNECED'],
            'P_DTINICIAL'        => $row['DTINICIAL'],
            'P_DTFINAL'          => $row['DTFINAL'],
            'P_CDQUALIF'         => $row['CDQUALIF'],
            'P_TODOS'            => $row['ALLDATE'],
            'P_NOVADATA'         => $row['NOVADTVALIDADE'],
            'P_PERMITE'          => $row['PERMITE'],
            'P_NPERMITE'         => $row['NPERMITE'],
            'P_NDEFINIDO'        => $row['NDEFINIDO'],
        ];
        
        $query = "UPDATE
                        FORNECEDOR F
                    SET
                      F.DTVALQUALIF = :P_NOVADATA
                    WHERE
                       ((INSTR(:P_CDFORNECED, F.CDFORNECED) <> 0) OR :P_CDFORNECED = 'T')              AND
                       ((F.DTVALQUALIF  BETWEEN :P_DTINICIAL  AND :P_DTFINAL) OR (:P_TODOS = 'T'))  AND
                       EXISTS ( SELECT 5
                       			FROM QUALIFICACAO Q
                                WHERE
                       			  (Q.CDQUALIF = F.CDQUALIF) AND
                       	  		  ((INSTR(:P_CDQUALIF, Q.CDQUALIF) <> 0) OR :P_CDQUALIF = 'T') AND
                       		 	  ((Q.IDPERCOTCMP IN (:P_PERMITE, :P_NPERMITE)) OR (F.CDQUALIF IS NULL AND :P_NDEFINIDO = 'V')))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function updateHistoricoQualificacaoFornecedor ($row)
    {
        $params = [
            'TXHISQUALFOR' => $row['TXHISQUALFOR'],
            'CDFORNECED'   => $row['CDFORNECED'],
        ];
        
        $query = "UPDATE HISTQUALFORN
                  SET
                      TXHISQUALFOR = utl_raw.cast_to_raw(:TXHISQUALFOR)
                  WHERE
                      CDFORNECED = :CDFORNECED";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function updateDataQualificacaoCliente ($row)
    {
        $params = [
            'P_CDCLIENTE'        => $row['CDFORNECED'],
            'P_DTINICIAL'        => $row['DTINICIAL'],
            'P_DTFINAL'          => $row['DTFINAL'],
            'P_CDQUALIF'         => $row['CDQUALIF'],
            'P_TODOS'            => $row['ALLDATE'],
            'P_NOVADATA'         => $row['NOVADTVALIDADE'],
            'P_PERMITE'          => $row['PERMITE'],
            'P_NPERMITE'         => $row['NPERMITE'],
            'P_NDEFINIDO'        => $row['NDEFINIDO'],
        ];
        
        $query = "UPDATE
                        CLIENTE C
                    SET
                      C.DTVALQUALIC = :P_NOVADATA
                    WHERE
                       ((INSTR(:P_CDCLIENTE, C.CDCLIENTE) <> 0) OR :P_CDCLIENTE = 'T')              AND
                       ((C.DTVALQUALIC  BETWEEN :P_DTINICIAL  AND :P_DTFINAL) OR (:P_TODOS = 'T'))  AND
                       EXISTS ( SELECT 5
                       			FROM QUALIFICACAO Q
                                WHERE
                       			  (Q.CDQUALIF = C.CDQUALIF) AND
                       	  		  ((INSTR(:P_CDQUALIF, Q.CDQUALIF) <> 0) OR :P_CDQUALIF = 'T') AND
                       		 	  ((Q.IDPERCOTCMP IN (:P_PERMITE, :P_NPERMITE)) OR (C.CDQUALIF IS NULL AND :P_NDEFINIDO = 'V')))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function updateHistoricoQualificacaoCliente ($row)
    {
        $params = [
            'TXHISQUALCLI' => $row['TXHISQUALCLI'],
            'P_CDCLIENTE'  => $row['CDCLIENTE'],
        ];
        
        $query = "UPDATE HISTQUALCLIE
                  SET
                      TXHISQUALCLI = utl_raw.cast_to_raw(:TXHISQUALCLI)
                  WHERE
                      CDCLIENTE = :P_CDCLIENTE";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function updateDataQualificacaoProspect ($row)
    {
        $params = [
            'P_CDPROSPECT'       => $row['CDFORNECED'],
            'P_DTINICIAL'        => $row['DTINICIAL'],
            'P_DTFINAL'          => $row['DTFINAL'],
            'P_CDQUALIF'         => $row['CDQUALIF'],
            'P_TODOS'            => $row['ALLDATE'],
            'P_NOVADATA'         => $row['NOVADTVALIDADE'],
            'P_PERMITE'          => $row['PERMITE'],
            'P_NPERMITE'         => $row['NPERMITE'],
            'P_NDEFINIDO'        => $row['NDEFINIDO'],
        ];
        
        $query = "UPDATE
                        PROSPECT P
                    SET
                      P.DTVALQUALIP = :P_NOVADATA
                    WHERE
                       ((INSTR(:P_CDPROSPECT, P.CDPROSPECT) <> 0) OR :P_CDPROSPECT = 'T')              AND
                       ((P.DTVALQUALIP  BETWEEN :P_DTINICIAL  AND :P_DTFINAL) OR (:P_TODOS = 'T'))  AND
                       EXISTS ( SELECT 5
                       			FROM QUALIFICACAO Q
                                WHERE
                       			  (Q.CDQUALIF = P.CDQUALIF) AND
                       	  		  ((INSTR(:P_CDQUALIF, Q.CDQUALIF) <> 0) OR :P_CDQUALIF = 'T') AND
                       		 	  ((Q.IDPERCOTCMP IN (:P_PERMITE, :P_NPERMITE)) OR (P.CDQUALIF IS NULL AND :P_NDEFINIDO = 'V')))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function updateHistoricoQualificacaoProspect ($row)
    {
        $params = [
            'TXHISQUALPRO' => $row['TXHISQUALPRO'],
            'CDPROSPECT'   => $row['CDPROSPECT'],
        ];
        
        $query = "UPDATE HISTQUALPROS
                  SET
                      TXHISQUALPRO = utl_raw.cast_to_raw(:TXHISQUALPRO)
                  WHERE
                      CDPROSPECT = :CDPROSPECT";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }

    public function insertJustQualificacaoProspect ($row)
    {
        $params = [
            'P_CDPROSPECT'       => $row['CDPROSPECT'],
            'P_DSLOGQUALIF'      => $row['DSLOGQUALIF'],
            'P_DSLOGJUSTQUALIF'  => $row['TXHISQUALFOR'],
            'P_CDOPERADOR'       => $this->environment->getCdOperador(),
        ];

        $query = "INSERT INTO LOGQUALIFICACAO
                    (CDPROSPECT, DSLOGQUALIF, DSLOGJUSTQUALIF, CDOPERADOR, DTULTATU)
                  VALUES
                      (:P_CDPROSPECT, :P_DSLOGQUALIF, :P_DSLOGJUSTQUALIF, :P_CDOPERADOR, SYSDATE)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function updateDataQualificacaoFabricante ($row)
    {
        
        $params = [
            'P_CDFABRIC'         => $row['CDFORNECED'],
            'P_DTINICIAL'        => $row['DTINICIAL'],
            'P_DTFINAL'          => $row['DTFINAL'],
            'P_CDQUALIF'         => $row['CDQUALIF'],
            'P_TODOS'            => $row['ALLDATE'],
            'P_NOVADATA'         => $row['NOVADTVALIDADE'],
            'P_PERMITE'          => $row['PERMITE'],
            'P_NPERMITE'         => $row['NPERMITE'],
            'P_NDEFINIDO'        => $row['NDEFINIDO'],
        ];
        $query = "UPDATE
                        FABRICANTE B
                    SET
                        B.DTVALQUALIF = :P_NOVADATA
                    WHERE
                       ((INSTR(:P_CDFABRIC, B.CDFABRIC) <> 0) OR :P_CDFABRIC = 'T')              AND
                       ((B.DTVALQUALIF  BETWEEN :P_DTINICIAL  AND :P_DTFINAL) OR (:P_TODOS = 'T'))  AND
                       EXISTS ( SELECT 5
                       			FROM QUALIFICACAO Q
                                WHERE
                       			  (Q.CDQUALIF = B.CDQUALIF) AND
                       	  		  ((INSTR(:P_CDQUALIF, Q.CDQUALIF) <> 0) OR :P_CDQUALIF = 'T') AND
                       		 	  ((Q.IDPERCOTCMP IN (:P_PERMITE, :P_NPERMITE)) OR (B.CDQUALIF IS NULL AND :P_NDEFINIDO = 'V')))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function insertJustQualificacaoFabricante ($row)
    {
        $params = [
            'P_CDFABRICANTE'     => $row['CDFABRIC'],
            'P_DSLOGQUALIF'      => $row['DSLOGQUALIF'],
            'P_DSLOGJUSTQUALIF'  => $row['TXHISQUALFOR'],
            'P_CDOPERADOR'       => $this->environment->getCdOperador(),
        ];
        $query = "INSERT INTO LOGQUALIFICACAO
                    (CDFABRICANTE, DSLOGQUALIF, DSLOGJUSTQUALIF, CDOPERADOR, DTULTATU)
                  VALUES
                      (:P_CDFABRICANTE, :P_DSLOGQUALIF, :P_DSLOGJUSTQUALIF, :P_CDOPERADOR, SYSDATE)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    
    public function updateHistoricoQualificacaoFabricante ($row)
    {
        $params = [
            'TXHISQUALFAB' => $row['TXHISQUALFAB'],
            'CDFABRIC'     => $row['CDFABRIC'],
        ];
        
        $query = "UPDATE HISTQUALFAB
                  SET
                      TXHISQUALFAB = utl_raw.cast_to_raw(:TXHISQUALFAB)
                  WHERE
                      CDFABRICANTE = :CDFABRIC";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    /********************
     *      INSERTS     *
     * ******************/
     
    public function insertLogQualificacaoFornecedor ($row)
    {
        $params = [
            'P_MENSQUALIFICACAO' => 'Alteração Automática da Validade de Qualificação para ',
            'P_NOVADATA'         => $row['NOVADTVALIDADE'],
            'P_JUSTIFICATIVA'    => $row['TXHISQUALFOR'],
            'P_OPERADOR'         => $this->environment->getCdOperador(),
            'P_CDFORNECED'       => $row['CDFORNECED'],
            'P_DTINICIAL'        => $row['DTINICIAL'],
            'P_DTFINAL'          => $row['DTFINAL'],
            'P_TODOS'            => $row['ALLDATE'],
            'P_CDQUALIF'         => $row['CDQUALIF'],
            'P_PERMITE'          => $row['PERMITE'],
            'P_NPERMITE'         => $row['NPERMITE'],
            'P_NDEFINIDO'        => $row['NDEFINIDO'],
        ];
        
        $query = "INSERT INTO LOGQUALIFICACAO (CDFORNECED, DSLOGQUALIF, DSLOGJUSTQUALIF, CDOPERADOR, DTULTATU)
                    SELECT
                       F.CDFORNECED,
                       :P_MENSQUALIFICACAO||:P_NOVADATA,
                       :P_JUSTIFICATIVA,
                       :P_OPERADOR,
                       SYSDATE
                    FROM FORNECEDOR F
                    WHERE
                       ((INSTR(:P_CDFORNECED, F.CDFORNECED) <> 0) OR :P_CDFORNECED = 'T') AND
                       ((F.DTVALQUALIF  BETWEEN :P_DTINICIAL  AND :P_DTFINAL) OR (:P_TODOS = 'T'))  AND
                       EXISTS ( SELECT 5
                       			FROM QUALIFICACAO Q
                                WHERE
                       			  (Q.CDQUALIF = F.CDQUALIF) AND
                       	  		  ((INSTR(:P_CDQUALIF, Q.CDQUALIF) <> 0) OR :P_CDQUALIF = 'T') AND
                       		 	  ((Q.IDPERCOTCMP IN (:P_PERMITE, :P_NPERMITE)) OR (F.CDQUALIF IS NULL AND :P_NDEFINIDO = 'V')))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function insertJustQualificacaoFornecedor ($row)
    {
        $params = [
            'P_CDFORNECED'       => $row['CDFORNECED'],
            'P_DSLOGQUALIF'      => $row['DSLOGQUALIF'],
            'P_DSLOGJUSTQUALIF'  => $row['TXHISQUALFOR'],
            'P_CDOPERADOR'       => $this->environment->getCdOperador(),
        ];
        $query = "INSERT INTO LOGQUALIFICACAO
                    (CDFORNECED, DSLOGQUALIF, DSLOGJUSTQUALIF, CDOPERADOR, DTULTATU)
                  VALUES
                      (:P_CDFORNECED, :P_DSLOGQUALIF, :P_DSLOGJUSTQUALIF, :P_CDOPERADOR, SYSDATE)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function insertHistoricoQualificacaoFornecedor ($row)
    {
        $params = [
            'CDFORNECED'   => $row['CDFORNECED'],
            'TXHISQUALFOR' => $row['TXHISQUALFOR'],
        ];
        
        $query = "INSERT INTO HISTQUALFORN
                      (CDFORNECED, TXHISQUALFOR)
                    VALUES
                      (:CDFORNECED, utl_raw.cast_to_raw(:TXHISQUALFOR))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function insertLogQualificacaoCliente ($row)
    {
        $params = [
            'P_MENSQUALIFICACAO' => 'Alteração Automática da Validade de Qualificação para ',
            'P_NOVADATA'         => $row['NOVADTVALIDADE'],
            'P_JUSTIFICATIVA'    => $row['TXHISQUALFOR'],
            'P_OPERADOR'         => $this->environment->getCdOperador(),
            'P_CDFORNECED'       => $row['CDFORNECED'],
            'P_DTINICIAL'        => $row['DTINICIAL'],
            'P_DTFINAL'          => $row['DTFINAL'],
            'P_TODOS'            => $row['ALLDATE'],
            'P_CDQUALIF'         => $row['CDQUALIF'],
            'P_PERMITE'          => $row['PERMITE'],
            'P_NPERMITE'         => $row['NPERMITE'],
            'P_NDEFINIDO'        => $row['NDEFINIDO'],
        ];
        
        $query = "INSERT INTO LOGQUALIFICACAO (CDCLIENTE, DSLOGQUALIF, DSLOGJUSTQUALIF, CDOPERADOR, DTULTATU)
                    SELECT
                       C.CDCLIENTE,
                       :P_MENSQUALIFICACAO||:P_NOVADATA,
                       :P_JUSTIFICATIVA,
                       :P_OPERADOR,
                       SYSDATE
                    FROM CLIENTE C
                    WHERE
                       ((INSTR(:P_CDFORNECED, C.CDCLIENTE) <> 0) OR :P_CDFORNECED = 'T') AND
                       ((C.DTVALQUALIC  BETWEEN :P_DTINICIAL  AND :P_DTFINAL) OR (:P_TODOS = 'T')) AND
                       EXISTS ( SELECT 5
                       			FROM QUALIFICACAO Q
                                WHERE
                       			  (Q.CDQUALIF = C.CDQUALIF) AND
                       	  		  ((INSTR(:P_CDQUALIF, Q.CDQUALIF) <> 0) OR :P_CDQUALIF = 'T') AND
                       		 	  ((Q.IDPERCOTCMP IN (:P_PERMITE, :P_NPERMITE)) OR (C.CDQUALIF IS NULL AND :P_NDEFINIDO = 'V')))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function insertJustQualificacaoCliente ($row)
    {
        $params = [
            'P_CDCLIENTE'        => $row['CDCLIENTE'],
            'P_DSLOGQUALIF'      => $row['DSLOGQUALIF'],
            'P_DSLOGJUSTQUALIF'  => $row['TXHISQUALCLI'],
            'P_CDOPERADOR'       => $this->environment->getCdOperador(),
        ];
        $query = "INSERT INTO LOGQUALIFICACAO
                    (CDCLIENTE, DSLOGQUALIF, DSLOGJUSTQUALIF, CDOPERADOR, DTULTATU)
                  VALUES
                    (:P_CDCLIENTE, :P_DSLOGQUALIF, :P_DSLOGJUSTQUALIF, :P_CDOPERADOR, SYSDATE)";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function insertHistoricoQualificacaoCliente ($row)
    {
        $params = [
            'CDCLIENTE'    => $row['CDCLIENTE'],
            'TXHISQUALCLI' => $row['TXHISQUALCLI'],
        ];
        
        $query = "INSERT INTO HISTQUALCLIE
                      (CDCLIENTE, TXHISQUALCLI)
                    VALUES
                      (:CDCLIENTE, utl_raw.cast_to_raw(:TXHISQUALCLI))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function insertLogQualificacaoProspect ($row)
    {
        $params = [
            'P_MENSQUALIFICACAO' => 'Alteração Automática da Validade de Qualificação para ',
            'P_NOVADATA'         => $row['NOVADTVALIDADE'],
            'P_JUSTIFICATIVA'    => $row['TXHISQUALFOR'],
            'P_OPERADOR'         => $this->environment->getCdOperador(),
            'P_CDFORNECED'       => $row['CDFORNECED'],
            'P_DTINICIAL'        => $row['DTINICIAL'],
            'P_DTFINAL'          => $row['DTFINAL'],
            'P_TODOS'            => $row['ALLDATE'],
            'P_CDQUALIF'         => $row['CDQUALIF'],
            'P_PERMITE'          => $row['PERMITE'],
            'P_NPERMITE'         => $row['NPERMITE'],
            'P_NDEFINIDO'        => $row['NDEFINIDO'],
        ];
        
        $query = "INSERT INTO LOGQUALIFICACAO (CDPROSPECT, DSLOGQUALIF, DSLOGJUSTQUALIF, CDOPERADOR, DTULTATU)
                    SELECT
                       P.CDPROSPECT,
                       :P_MENSQUALIFICACAO||:P_NOVADATA,
                       :P_JUSTIFICATIVA,
                       :P_OPERADOR,
                       SYSDATE
                    FROM PROSPECT P
                    WHERE
                       ((INSTR(:P_CDFORNECED, P.CDPROSPECT) <> 0) OR :P_CDFORNECED = 'T') AND
                       ((P.DTVALQUALIP  BETWEEN :P_DTINICIAL  AND :P_DTFINAL) OR (:P_TODOS = 'T')) AND
                       EXISTS ( SELECT 5
                       			FROM QUALIFICACAO Q
                                WHERE
                       			  (Q.CDQUALIF = P.CDQUALIF) AND
                       	  		  ((INSTR(:P_CDQUALIF, Q.CDQUALIF) <> 0) OR :P_CDQUALIF = 'T') AND
                       		 	  ((Q.IDPERCOTCMP IN (:P_PERMITE, :P_NPERMITE)) OR (P.CDQUALIF IS NULL AND :P_NDEFINIDO = 'V')))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function insertHistoricoQualificacaoProspect ($row)
    {
        $params = [
            'CDPROSPECT'    => $row['CDPROSPECT'],
            'TXHISQUALPRO'  => $row['TXHISQUALPRO'],
        ];
        
        $query = "INSERT INTO HISTQUALPROS
                      (CDPROSPECT, TXHISQUALPRO)
                    VALUES
                      (:CDPROSPECT, utl_raw.cast_to_raw(:TXHISQUALPRO))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function insertLogQualificacaoFabricante ($row)
    {
        $params = [
            'P_MENSQUALIFICACAO' => 'Alteração Automática da Validade de Qualificação para ',
            'P_NOVADATA'         => $row['NOVADTVALIDADE'],
            'P_JUSTIFICATIVA'    => $row['TXHISQUALFOR'],
            'P_OPERADOR'         => $this->environment->getCdOperador(),
            'P_CDFORNECED'       => $row['CDFORNECED'],
            'P_DTINICIAL'        => $row['DTINICIAL'],
            'P_DTFINAL'          => $row['DTFINAL'],
            'P_TODOS'            => $row['ALLDATE'],
            'P_CDQUALIF'         => $row['CDQUALIF'],
            'P_PERMITE'          => $row['PERMITE'],
            'P_NPERMITE'         => $row['NPERMITE'],
            'P_NDEFINIDO'        => $row['NDEFINIDO'],
        ];
        
        $query = "INSERT INTO LOGQUALIFICACAO (CDFABRICANTE, DSLOGQUALIF, DSLOGJUSTQUALIF, CDOPERADOR, DTULTATU)
                    SELECT
                       B.CDFABRIC AS CDFABRICANTE,
                       :P_MENSQUALIFICACAO||:P_NOVADATA,
                       :P_JUSTIFICATIVA,
                       :P_OPERADOR,
                       SYSDATE
                    FROM FABRICANTE B
                    WHERE
                       ((INSTR(:P_CDFORNECED, B.CDFABRIC) <> 0) OR :P_CDFORNECED = 'T') AND
                       ((B.DTVALQUALIF  BETWEEN :P_DTINICIAL  AND :P_DTFINAL) OR (:P_TODOS = 'T')) AND
                       EXISTS ( SELECT 5
                       			FROM QUALIFICACAO Q
                                WHERE
                       			  (Q.CDQUALIF = B.CDQUALIF) AND
                       	  		  ((INSTR(:P_CDQUALIF, Q.CDQUALIF) <> 0) OR :P_CDQUALIF = 'T') AND
                       		 	  ((Q.IDPERCOTCMP IN (:P_PERMITE, :P_NPERMITE)) OR (B.CDQUALIF IS NULL AND :P_NDEFINIDO = 'V')))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
    public function insertHistoricoQualificacaoFabricante ($row)
    {
        $params = [
            'CDFABRIC'     => $row['CDFABRIC'],
            'TXHISQUALFAB' => $row['TXHISQUALFAB'],
        ];
        
        $query = "INSERT INTO HISTQUALFAB
                      (CDFABRICANTE, TXHISQUALFAB)
                    VALUES
                      (:CDFABRIC, utl_raw.cast_to_raw(:TXHISQUALFAB))";
        try {
            $std = $this->connection->prepare($query);
            $std->execute($params);
        } catch (Exception $e) {
            throw $e;
        }
    }
}